==> bushelpowered-bushel-interfaces-1.6.25-936050.tar: Bushelpowered/Api/Quoting/V1/Response/QuoteDetailResponse.php <==
<?php
namespace Bushelpowered\Api\Quoting\V1\Response;
        
class QuoteDetailResponse implements \Bushelpowered\Api\Common\HasCreatedAtTimestamp, \Bushelpowered\Api\Common\HasUpdatedAtTimestamp, \Bushelpowered\Api\Common\HasCreatedBy, \Bushelpowered\Api\Common\HasUpdatedBy
{
    /** @var string $id The primary unique identifier.*/
    public string $id;
    /** @var string $accountId The UUID of the account associated with the quote*/
    public string $accountId;
    /** @var string $name The name of the quote*/
    public string $name;
    /** @var null|string $commodityId The UUID of the commodity associated with the quote*/
    public ?string $commodityId = null;
    /** @var string $customerName The name of the customer associated with the quote*/
    public string $customerName;
    /** @var string $fieldNames The field names for the quote*/
    public string $fieldNames;
    /** @var null|int $area The acres/hectares for the quote*/
    public ?int $area = null;
    /** @var \Bushelpowered\Api\Quoting\V1\Enums\AreaUoM $areaUoM */
    public \Bushelpowered\Api\Quoting\V1\Enums\AreaUoM $areaUoM;
    /** @var null|int $cropYear The crop year of the quote*/
    public ?int $cropYear = null;
    /** @var string $creationDate The creation date of the quote of yyyy-MM-dd format, IE: 2023-10-04*/
    public string $creationDate;
    /** @var string $customerComments The customer's comments for the quote*/
    public string $customerComments;
    /** @var \Bushelpowered\Api\Quoting\V1\Enums\QuoteStatus $status */
    public \Bushelpowered\Api\Quoting\V1\Enums\QuoteStatus $status;
    /** @var \Bushelpowered\Api\Quoting\V1\Response\LineItemResponse[] $lineItems */
    public array $lineItems;
    /** @var \Bushelpowered\Api\Quoting\V1\Response\ServiceFeeResponse[] $serviceFees */
    public array $serviceFees;
    /** @var null|string $expiresOn The expiration date of the quote of yyyy-MM-dd format, IE: 2023-10-04*/
    public ?string $expiresOn = null;
    /** @var string $staffComments The staff's comments for the quote*/
    public string $staffComments;
    /** @var \Bushelpowered\Api\Quoting\V1\Response\DiscountResponse[] $discounts */
    public array $discounts;
    /** @var float $lineItemsTotal The total of line item prices*/
    public float $lineItemsTotal;
    /** @var float $quoteTotal The total of line item prices plus services minus discounts*/
    public float $quoteTotal;
    /** @var string $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var string $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;
    /** @var string $createdBy Created by UUID within the microservice.*/
    public string $createdBy;
    /** @var string $updatedBy Updated by UUID within the microservice.*/
    public string $updatedBy;

    /**
     * @param  string  $id The primary unique identifier.
     * @param  string  $accountId The UUID of the account associated with the quote
     * @param  string  $name The name of the quote
     * @param  null|string  $commodityId The UUID of the commodity associated with the quote
     * @param  string  $customerName The name of the customer associated with the quote
     * @param  string  $fieldNames The field names for the quote
     * @param  null|int  $area The acres/hectares for the quote
     * @param  \Bushelpowered\Api\Quoting\V1\Enums\AreaUoM  $areaUoM 
     * @param  null|int  $cropYear The crop year of the quote
     * @param  string  $creationDate The creation date of the quote of yyyy-MM-dd format, IE: 2023-10-04
     * @param  string  $customerComments The customer's comments for the quote
     * @param  \Bushelpowered\Api\Quoting\V1\Enums\QuoteStatus  $status 
     * @param  \Bushelpowered\Api\Quoting\V1\Response\LineItemResponse[]  $lineItems 
     * @param  \Bushelpowered\Api\Quoting\V1\Response\ServiceFeeResponse[]  $serviceFees 
     * @param  null|string  $expiresOn The expiration date of the quote of yyyy-MM-dd format, IE: 2023-10-04
     * @param  string  $staffComments The staff's comments for the quote
     * @param  \Bushelpowered\Api\Quoting\V1\Response\DiscountResponse[]  $discounts 
     * @param  float  $lineItemsTotal The total of line item prices
     * @param  float  $quoteTotal The total of line item prices plus services minus discounts
     * @param  string  $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $createdBy Created by UUID within the microservice.
     * @param  string  $updatedBy Updated by UUID within the microservice.
     */
    public function __construct(string $id, string $accountId, string $name, ?string $commodityId, string $customerName, string $fieldNames, ?int $area, \Bushelpowered\Api\Quoting\V1\Enums\AreaUoM $areaUoM, ?int $cropYear, string $creationDate, string $customerComments, \Bushelpowered\Api\Quoting\V1\Enums\QuoteStatus $status, array $lineItems, array $serviceFees, ?string $expiresOn, string $staffComments, array $discounts, float $lineItemsTotal, float $quoteTotal, string $createdAt, string $updatedAt, string $createdBy, string $updatedBy)
    {
        $this->id = $id;
        $this->accountId = $accountId;
        $this->name = $name;
        $this->commodityId = $commodityId;
        $this->customerName = $customerName;
        $this->fieldNames = $fieldNames;
        $this->area = $area;
        $this->areaUoM = $areaUoM;
        $this->cropYear = $cropYear;
        $this->creationDate = $creationDate;
        $this->customerComments = $customerComments;
        $this->status = $status;
        $this->lineItems = $lineItems;
        $this->serviceFees = $serviceFees;
        $this->expiresOn = $expiresOn;
        $this->staffComments = $staffComments;
        $this->discounts = $discounts;
        $this->lineItemsTotal = $lineItemsTotal;
        $this->quoteTotal = $quoteTotal;
        $this->createdAt = $createdAt;
        $this->updatedAt = $updatedAt;
        $this->createdBy = $createdBy;
        $this->updatedBy = $updatedBy;
    }
    
    /**
     * @return string Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return string Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
    /**
     * @return string Created by UUID within the microservice.
     */
    public function getCreatedBy(): string
    {
        return $this->createdBy;
    }
    /**
     * @return string Updated by UUID within the microservice.
     */
    public function getUpdatedBy(): string
    {
        return $this->updatedBy;
    }
}

==> bushelpowered-bushel-interfaces-1.6.306-5a7510.tar: Bushelpowered/Api/Quoting/V1/Response/QuoteDetailResponse.php <==
<?php
namespace Bushelpowered\Api\Quoting\V1\Response;
        
class QuoteDetailResponse implements \Bushelpowered\Api\Common\HasCreatedAtTimestamp, \Bushelpowered\Api\Common\HasUpdatedAtTimestamp, \Bushelpowered\Api\Common\HasCreatedBy, \Bushelpowered\Api\Common\HasUpdatedBy
{
    /** @var string $id The primary unique identifier.*/
    public string $id;
    /** @var string $accountId The UUID of the account associated with the quote*/
    public string $accountId;
    /** @var string $name The name of the quote*/
    public string $name;
    /** @var null|string $commodityId The UUID of the commodity associated with the quote*/
    public ?string $commodityId = null;
    /** @var string $customerName The name of the customer associated with the quote*/
    public string $customerName;
    /** @var string $fieldNames The field names for the quote*/
    public string $fieldNames;
    /** @var null|int $area The acres/hectares for the quote*/
    public ?int $area = null;
    /** @var \Bushelpowered\Api\Quoting\V1\Enums\AreaUoM $areaUoM */
    public \Bushelpowered\Api\Quoting\V1\Enums\AreaUoM $areaUoM;
    /** @var null|int $cropYear The crop year of the quote*/
    public ?int $cropYear = null;
    /** @var string $creationDate The creation date of the quote of yyyy-MM-dd format, IE: 2023-10-04*/
    public string $creationDate;
    /** @var null|string $expiresOn The expiration date of the quote of yyyy-MM-dd format, IE: 2023-10-04*/
    public ?string $expiresOn = null;
    /** @var null|string $preparedBy The UUID of the staff user that prepared the quote*/
    public ?string $preparedBy = null;
    /** @var \Bushelpowered\Api\Quoting\V1\Enums\QuoteStatus $status */
    public \Bushelpowered\Api\Quoting\V1\Enums\QuoteStatus $status;
    /** @var string $customerComments The customer's comments for the quote*/
    public string $customerComments;
    /** @var string $staffComments The staff's comments for the quote*/
    public string $staffComments;
    /** @var \Bushelpowered\Api\Quoting\V1\Response\LineItemResponse[] $lineItems */
    public array $lineItems;
    /** @var \Bushelpowered\Api\Quoting\V1\Response\ServiceResponse[] $services */
    public array $services;
    /** @var \Bushelpowered\Api\Quoting\V1\Response\DiscountResponse[] $discounts */
    public array $discounts;
    /** @var null|float $lineItemsTotal The total of line item prices*/
    public ?float $lineItemsTotal = null;
    /** @var null|float $discountsTotal The total of discount values*/
    public ?float $discountsTotal = null;
    /** @var null|float $servicesTotal The total of service values*/
    public ?float $servicesTotal = null;
    /** @var null|float $quoteTotal The total of line item prices plus services minus discounts*/
    public ?float $quoteTotal = null;
    /** @var string $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var string $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;
    /** @var string $createdBy Created by UUID within the microservice.*/
    public string $createdBy;
    /** @var string $updatedBy Updated by UUID within the microservice.*/
    public string $updatedBy;

    /**
     * @param  string  $id The primary unique identifier.
     * @param  string  $accountId The UUID of the account associated with the quote
     * @param  string  $name The name of the quote
     * @param  null|string  $commodityId The UUID of the commodity associated with the quote
     * @param  string  $customerName The name of the customer associated with the quote
     * @param  string  $fieldNames The field names for the quote
     * @param  null|int  $area The acres/hectares for the quote
     * @param  \Bushelpowered\Api\Quoting\V1\Enums\AreaUoM  $areaUoM 
     * @param  null|int  $cropYear The crop year of the quote
     * @param  string  $creationDate The creation date of the quote of yyyy-MM-dd format, IE: 2023-10-04
     * @param  null|string  $expiresOn The expiration date of the quote of yyyy-MM-dd format, IE: 2023-10-04
     * @param  null|string  $preparedBy The UUID of the staff user that prepared the quote
     * @param  \Bushelpowered\Api\Quoting\V1\Enums\QuoteStatus  $status 
     * @param  string  $customerComments The customer's comments for the quote
     * @param  string  $staffComments The staff's comments for the quote
     * @param  \Bushelpowered\Api\Quoting\V1\Response\LineItemResponse[]  $lineItems 
     * @param  \Bushelpowered\Api\Quoting\V1\Response\ServiceResponse[]  $services 
     * @param  \Bushelpowered\Api\Quoting\V1\Response\DiscountResponse[]  $discounts 
     * @param  null|float  $lineItemsTotal The total of line item prices
     * @param  null|float  $discountsTotal The total of discount values
     * @param  null|float  $servicesTotal The total of service values
     * @param  null|float  $quoteTotal The total of line item prices plus services minus discounts
     * @param  string  $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $createdBy Created by UUID within the microservice.
     * @param  string  $updatedBy Updated by UUID within the microservice.
     */
    public function __construct(string $id, string $accountId, string $name, ?string $commodityId, string $customerName, string $fieldNames, ?int $area, \Bushelpowered\Api\Quoting\V1\Enums\AreaUoM $areaUoM, ?int $cropYear, string $creationDate, ?string $expiresOn, ?string $preparedBy, \Bushelpowered\Api\Quoting\V1\Enums\QuoteStatus $status, string $customerComments, string $staffComments, array $lineItems, array $services, array $discounts, ?float $lineItemsTotal, ?float $discountsTotal, ?float $servicesTotal, ?float $quoteTotal, string $createdAt, string $updatedAt, string $createdBy, string $updatedBy)
    {
        $this->id = $id;
        $this->accountId = $accountId;
        $this->name = $name;
        $this->commodityId = $commodityId;
        $this->customerName = $customerName;
        $this->fieldNames = $fieldNames;
        $this->area = $area;
        $this->areaUoM = $areaUoM;
        $this->cropYear = $cropYear;
        $this->creationDate = $creationDate;
        $this->expiresOn = $expiresOn;
        $this->preparedBy = $preparedBy;
        $this->status = $status;
        $this->customerComments = $customerComments;
        $this->staffComments = $staffComments;
        $this->lineItems = $lineItems;
        $this->services = $services;
        $this->discounts = $discounts;
        $this->lineItemsTotal = $lineItemsTotal;
        $this->discountsTotal = $discountsTotal;
        $this->servicesTotal = $servicesTotal;
        $this->quoteTotal = $quoteTotal;
        $this->createdAt = $createdAt;
        $this->updatedAt = $updatedAt;
        $this->createdBy = $createdBy;
        $this->updatedBy = $updatedBy;
    }
    
    /**
     * @return string Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return string Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
    /**
     * @return string Created by UUID within the microservice.
     */
    public function getCreatedBy(): string
    {
        return $this->createdBy;
    }
    /**
     * @return string Updated by UUID within the microservice.
     */
    public function getUpdatedBy(): string
    {
        return $this->updatedBy;
    }
}
